"""Smartcard utility module.

The smartcard utility module provides classes and functions to
access smartcards and readers.

__author__ = "gemalto http://www.gemalto.com"
__date__ = "May 2010"
__version__ = "1.6.10"

Copyright 2001-2010 gemalto
Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com

This file is part of pyscard.

pyscard is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 2.1 of the License, or
(at your option) any later version.

pyscard is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with pyscard; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
"""

__all__ = [
             'listReaders',
             'Session'
          ]


# for legacy only
from smartcard.System import listReaders
from smartcard.Session import Session
